@@ -11,7 +11,7 @@ describe '...' do
 
   it 'should raise an error when trying to do operations without being logged in' do
     error_msg = 'Anonymous gists are no longer supported. Please log in with `gist --login`. ' \
-      '(Github now requires credentials to gist https://bit.ly/2GBBxKw)'
+      '(GitHub now requires credentials to gist https://bit.ly/2GBBxKw)'
 
     expect do
       Gist.gist("Test gist", output: :raw_url, anonymous: true)
